@@ -20,6 +20,7 @@ from phootonics_controller.base_controllers.config import VCM_PORT, CAVITY1_INDE
 from phootonics_controller.base_controllers.stage_mock import MockStageController
 from phootonics_controller.base_controllers.xc_controller import ECController, MockECController
 from phootonics_controller.base_controllers.stage_vcm import VCMirrorController
+from phootonics_controller.utils.ADC_converter.ADS1263 import ADS1263_CMD
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -60,6 +61,8 @@ class ADCDevice:
     def read_fast(self):
         try:
             adc_value = self._adc.ADS1263_GetChannalValue(ADC_CHANNEL)
+            self._adc.ADS1263_WriteCmd(ADS1263_CMD['CMD_STOP1'])
+            time.sleep(20.0/1000.0)
             if adc_value >> 31 == 1:
                 value = REF * 2 - adc_value * REF / 0x80000000
             else:
